Crate sos_external_files

Crate sos_external_files 

Structs

EncryptedFile
Meta data about an encrypted file.
FileSource
Source path to a file.
FileStorageDiff
Diff of file secrets.
FileStorageResult
Result of encrypting an external file.

Enums

FileMutationEvent
Wraps the file storage information and a related file event that can be persisted to an event log.
FileProgress
File progress operations.

Functions

list_external_files
List all the external files in an account by reading the state from disc.
list_folder_files
List all the external files in a folder.